ProjectConfiguration class

Constructors

ProjectConfiguration(List<Layer> layers, List<RegExp> excludePaths, Map<Layer, Set<Layer>> bannedImports, Map<Layer, Set<RegExp>> bannedClassNames)
ProjectConfiguration.fromMap(Map map)
factory

Properties

bannedClassNames Map<Layer, Set<RegExp>>
final
bannedImports Map<Layer, Set<Layer>>
final
excludePaths List<RegExp>
final
hashCode int
The hash code for this object.
no setterinherited
layers List<Layer>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited